%global __requires_exclude perl

Summary:	Fast anti-spam filtering by Bayesian statistical analysis
Name:		bogofilter
Version:	1.2.5
Release:	%mkrel 4
License:	GPLv2+
Group:		Networking/Mail
URL:		https://bogofilter.sourceforge.net/
Source0:	https://prdownloads.sourceforge.net/bogofilter/%{name}-%{version}.tar.xz
BuildRequires:	db-devel
BuildRequires:	pkgconfig(gsl)
BuildRequires:	valgrind
BuildRequires:	flex
BuildRequires:	openjade

%description
Bogofilter is a Bayesian spam filter. In its normal mode of
operation, it takes an email message or other text on standard
input, does a statistical check against lists of "good" and
"bad" words, and returns a status code indicating whether or not
the message is spam. Bogofilter is designed with fast algorithms
(including Berkeley DB system), coded directly in C, and tuned for
speed, so it can be used for production by sites that process a
lot of mail.

%prep
%setup -q

%build

%configure \
    --disable-rpath \
    --disable-transactions \
    --with-database=db \
    --disable-dependency-tracking \
    --without-included-gsl

%make_build

%ifnarch armv7hl
# Some strange test failures that would need to be investigated but don't seem fatal
# 3/54 Failed:
#./outputs/dump.load-2.out ./checks.23370.20160529T004141/dump.load-2.txt differ: char 87, line 3
#FAIL: t.dump.load
#want: "7.2 6.20030303 10.20030304", have: "1.2 6.20030303 10.20030304"
#FAIL: t.nonascii.replace
#./outputs/bulkmode.out ./checks.24400.20160529T004148/bulk-double-2.out differ: char 80, line 3
#FAIL: t.bulkmode
%check
make DESTDIR="%{buildroot}" check
%endif

%install
%make_install

mv %{buildroot}%{_sysconfdir}/bogofilter.cf.example %{buildroot}%{_sysconfdir}/bogofilter.cf

# trio is embedded and has different AUTHORS, CHANGES, README
mkdir -p %{buildroot}%{_datadir}/doc/%{name}/trio
cp trio/CHANGES %{buildroot}%{_datadir}/doc/%{name}/trio/CHANGES
cp trio/AUTHORS %{buildroot}%{_datadir}/doc/%{name}/trio/AUTHORS
cp trio/README %{buildroot}%{_datadir}/doc/%{name}/trio/README

##include contrib, some may find it useful
for d in contrib ; do
  install -d %{buildroot}%{_datadir}/%{name}/$d
  files=$(find "$d" -maxdepth 1 -type f -print)
  for f in $files ; do
    case $f in
      *.c|*.o|*.obj|*/Makefile*) continue ;;
      *.1)
    cp -p $f %{buildroot}%{_mandir}/man1 ;;
      *)
    cp -p $f %{buildroot}%{_datadir}/%{name}/$d ;;
    esac
  done
done

%files
%doc AUTHORS GETTING.STARTED Doxyfile NEWS
%doc README* OBITUARY TODO RELEASE.NOTES*
%doc bogofilter.cf.example
%doc doc/README* doc/bogofilter-SA*
%doc doc/integrating-* doc/*.html doc/*.xml
%doc contrib/README*
%doc %{_datadir}/doc/%{name}/trio
%config(noreplace) %{_sysconfdir}/bogofilter.cf
%{_bindir}/*
%{_datadir}/bogofilter
%{_mandir}/man1/*


%changelog
* Fri Dec 30 2022 daviddavid <daviddavid> 1.2.5-4.mga9
+ Revision: 1928028
- rebuild for gsl 2.7.1 on arrmv7

* Thu Dec 29 2022 daviddavid <daviddavid> 1.2.5-3.mga9
+ Revision: 1927499
- rebuild for new gsl 2.7.1

* Thu Mar 31 2022 umeabot <umeabot> 1.2.5-2.mga9
+ Revision: 1837678
- Mageia 9 Mass Rebuild
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sat Apr 18 2020 julien <julien> 1.2.5-1.mga8
+ Revision: 1569329
- new version 1.2.5
- spellcheck
- properly add doc for embedded trio
- simplify install of html/xml doc

* Sun Feb 16 2020 umeabot <umeabot> 1.2.4-10.mga8
+ Revision: 1529681
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 daviddavid <daviddavid> 1.2.4-9.mga8
+ Revision: 1433724
- rebuild for new gsl 2.6

* Fri Sep 21 2018 umeabot <umeabot> 1.2.4-8.mga7
+ Revision: 1295586
- Mageia 7 Mass Rebuild

* Wed Dec 27 2017 wally <wally> 1.2.4-7.mga7
+ Revision: 1185638
- rebuild for new gsl

* Tue Jun 28 2016 pterjan <pterjan> 1.2.4-6.mga6
+ Revision: 1038002
- Disable tests on armv7hl

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.2.4-5.mga6
+ Revision: 918998
- rebuild for gsl

* Wed Oct 15 2014 umeabot <umeabot> 1.2.4-4.mga5
+ Revision: 749287
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.4-3.mga5
+ Revision: 678191
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Mon Oct 21 2013 umeabot <umeabot> 1.2.4-2.mga4
+ Revision: 539496
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 julien <julien> 1.2.4-1.mga4
+ Revision: 492338
- new version 1.2.4

* Fri Jan 11 2013 umeabot <umeabot> 1.2.3-2.mga3
+ Revision: 346936
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 06 2012 julien <julien> 1.2.3-1.mga3
+ Revision: 327545
- new version 1.2.3

* Tue Jul 31 2012 fwang <fwang> 1.2.2-4.mga3
+ Revision: 276366
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 1.2.2-3.mga3
+ Revision: 274763
- build with system db

* Fri Feb 25 2011 ahmad <ahmad> 1.2.2-2.mga1
+ Revision: 59198
- imported package bogofilter


* Sun Jul 11 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.2.2-2mdv2011.0
+ Revision: 551171
- add a _requires_exceptions for perl, not needed (from Charles A Edwards)

* Sat Jul 10 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.2-1mdv2011.0
+ Revision: 550109
- update to new version 1.2.2

* Sat Jan 02 2010 Funda Wang <fwang@mandriva.org> 1.2.1-2mdv2010.1
+ Revision: 484939
- build for db4.8

* Fri Aug 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.2.1-1mdv2010.0
+ Revision: 416385
- update to new version 1.2.1

* Tue Feb 24 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.0-1mdv2009.1
+ Revision: 344436
- build against db4.7
- update to new version 1.2.0

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1.1.7-2mdv2009.0
+ Revision: 266301
- rebuild early 2009.0 package (before pixel changes)

* Wed May 07 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.7-1mdv2009.0
+ Revision: 202667
- new version
- drop patch 0 and 1, not usefull imho
- enable valgrind test
- add missing buildrequires

* Fri Jan 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.6-3mdv2008.1
+ Revision: 147813
- disable transactional mode in Berkeley DB, probably this causes bug #36504
- do not package INSTALL file

* Sun Dec 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.6-2mdv2008.1
+ Revision: 139395
- rebuild against db4.6
- new license policy
- do not package COPYING file

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 06 2007 Andreas Hasenack <andreas@mandriva.com> 1.1.6-1mdv2008.1
+ Revision: 116019
- updated to version 1.1.6

* Tue Sep 18 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.5-2mdv2008.0
+ Revision: 89868
- remove dead configure option
- disable rpath
- enable transactions
- use system gsl library
- compile with support with Berkeley's database
- spec file clean


* Mon Jan 15 2007 Andreas Hasenack <andreas@mandriva.com> 1.1.5-1mdv2007.0
+ Revision: 109070
- updated to version 1.1.5

* Tue Jan 02 2007 Andreas Hasenack <andreas@mandriva.com> 1.1.4-1mdv2007.1
+ Revision: 103125
- updated to version 1.1.4

* Fri Dec 22 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.1-1mdv2007.1
+ Revision: 101622
- Import bogofilter

* Fri Aug 25 2006 Charles A Edwards <eslrahc@mandriva.org> 1.1.1-1mdv2007.0
- 1.1.1
- drop patch1....fixed upstream
- drop source1-urpmi.readme....should no longer be needed

* Sat Aug 12 2006 Charles A Edwards <eslrahc@mandriva.org> 1.1.0-2mdv2007.0
- add patch from David Relson <relson@osagesoftware.com>
- re-enable make check

* Sat Aug 12 2006 Charles A Edwards <eslrahc@mandriva.org> 1.1.0-1mdv2007.0
- 1.1.0
- don't run make check

* Tue Jul 11 2006 Oden Eriksson <oeriksson@mandriva.com> 1.0.3-1mdk
- New release 1.0.3

* Mon May 08 2006 Jerome Soyer <saispo@mandriva.org> 1.0.2-1mdk
- New release 1.0.2

* Fri Feb 03 2006 Jerome Soyer <saispo@mandriva.org> 1.0.1-1mdk
- New release 1.0.1

* Fri Dec 02 2005 Lenny Cartier <lenny@mandriva.com> 1.0.0-1mdk
- 1.0.0

* Wed Nov 23 2005 Lenny Cartier <lenny@mandriva.com> 0.96.6-1mdk
- 0.96.6

* Thu Oct 13 2005 Oden Eriksson <oeriksson@mandriva.com> 0.96.2-1mdk
- 0.96.2

* Fri Jul 29 2005 Oden Eriksson <oeriksson@mandriva.com> 0.95.2-1mdk
- 0.95.2
- andreas:
  - added novalgrindtest patch so we can remove the buildconflicts
    for it

* Sat Apr 09 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94.4-1mdk
- 0.94.4

* Thu Mar 31 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94.3-1mdk
- 0.94.3

* Fri Mar 25 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94.2-1mdk
- 0.94.2

* Mon Mar 21 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94.1-2mdk
- include /contrib
- better placement og *.html and *.xml

* Wed Mar 16 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94.1-1mdk
- 0.94.1

* Mon Mar 07 2005 Charles A Edwards <eslrahc@mandrake.org> 0.94-1mdk
- new release
- builf with transactions

* Sun Jan 09 2005 Charles A Edwards <eslrahc@mandrake.org> 0.93.4-1mdk
- new release

* Mon Dec 27 2004 Charles A Edwards <eslrahc@mandrake.org> 0.93.3.1-1mdk
- new release

* Fri Dec 03 2004 Charles A Edwards <eslrahc@mandrake.org> 0.93.2-1mdk
- 0.93.2
- use db4.2
- simplify listing for bin and man

* Wed Nov 17 2004 Charles A Edwards <eslrahc@mandrake.org> 0.93.1-1mdk
- 0.93.1

* Sun Nov 07 2004 Charles A Edwards <eslrahc@mandrake.org> 0.93.0-1mdk
- 0.93
- READDME.urpmi

* Wed Oct 20 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.8-1mdk
- 0.92.8
- more updates to doc list

* Sat Oct 16 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.7-1mdk
- 0.92.7
- update doc list

* Tue Aug 24 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.6-1mdk
- 0.92.6

* Sat Aug 21 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.5-1mdk
- 0.92.5

* Sat Jul 31 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.4-1mdk
- 0.92.4

* Wed Jul 28 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.3-1mdk
- 0.92.3

* Fri Jul 16 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.2-1mdk
- 0.92.2

* Fri Jul 02 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.1-1mdk
- 0.92.1

* Mon Jun 28 2004 Charles A Edwards <eslrahc@mandrake.org> 0.92.0-1mdk
- 0.92.0

* Mon Jun 21 2004 Charles A Edwards <eslrahc@mandrake.org> 0.91.4-1mdk
- 0.91.4

* Thu Jun 17 2004 Charles A Edwards <eslrahc@mandrake.org> 0.91.3-1mdk
- 0.91.3

* Thu Jun 10 2004 Charles A Edwards <eslrahc@mandrake.org> 0.91.1-1mdk
- 0.91.1
- add buildconflict valgrind

* Sun May 23 2004 Charles A Edwards <eslrahc@mandrake.org> 0.91.0-1mdk
- 0.91.0
- drop BR for autoconf2.5--now default

* Mon May 10 2004 <Charles A Edwards <eslrahc@mandrake.org> 0.90.0-1mdk
- 0.90.0

* Fri Apr 02 2004 Charles A Edwards <eslrahc@mandrake.org> 0.17.4-1mdk
- 0.17.4

* Tue Feb 24 2004 Charles A Edwards <eslrahc@mandrake.org> 0.17.2-1mdk
- 0.17.2

